@@ -33,6 +33,7 @@
 
 #include "crawlerwidget.h"
 
+#include "persistentinfo.h"
 #include "configuration.h"
 
 // Palette for error signaling (yellow background)
@@ -272,7 +273,10 @@ void CrawlerWidget::keyPressEvent( QKeyEvent* keyEvent )
 void CrawlerWidget::startNewSearch()
 {
     // Record the search line in the recent list
+    // (reload the list first in case another glogg changed it)
+    GetPersistentInfo().retrieve( "savedSearches" );
     savedSearches->addRecent( searchLineEdit->currentText() );
+    GetPersistentInfo().save( "savedSearches" );
 
     // Update the SearchLine (history)
     updateSearchCombo();
@@ -301,12 +305,15 @@ void CrawlerWidget::updateFilteredView( int nbMatches, int progress )
     }
     else {
         // Search in progress
-        searchInfoLine->setText(
-                tr("Search in progress (%1 %)... %2 match%3 found so far.")
-                .arg( progress )
-                .arg( nbMatches )
-                .arg( nbMatches > 1 ? "es" : "" ) );
-        searchInfoLine->displayGauge( progress );
+        // We ignore 0% and 100% to avoid a flash when the search is very short
+        if ( progress > 0 ) {
+            searchInfoLine->setText(
+                    tr("Search in progress (%1 %)... %2 match%3 found so far.")
+                    .arg( progress )
+                    .arg( nbMatches )
+                    .arg( nbMatches > 1 ? "es" : "" ) );
+            searchInfoLine->displayGauge( progress );
+        }
     }
 
     // Recompute the content of the filtered window.
@@ -324,7 +331,8 @@ void CrawlerWidget::jumpToMatchingLine(int filteredLineNb)
 
 void CrawlerWidget::applyConfiguration()
 {
-    QFont font = Config().mainFont();
+    Configuration& config = Persistent<Configuration>( "settings" );
+    QFont font = config.mainFont();
 
     LOG(logDEBUG) << "CrawlerWidget::applyConfiguration";
 
@@ -463,7 +471,8 @@ void CrawlerWidget::replaceCurrentSearch( const QString& searchText )
     if ( !searchText.isEmpty() ) {
         // Determine the type of regexp depending on the config
         QRegExp::PatternSyntax syntax;
-        switch ( Config().mainRegexpType() ) {
+        Configuration& config = Persistent<Configuration>( "settings" );
+        switch ( config.mainRegexpType() ) {
             case Wildcard:
                 syntax = QRegExp::Wildcard;
                 break;
