@@ -29,17 +29,16 @@
 #include "mainwindow.h"
 
 #include "version.h"
+#include "sessioninfo.h"
+#include "recentfiles.h"
 #include "crawlerwidget.h"
 #include "filtersdialog.h"
 #include "optionsdialog.h"
+#include "persistentinfo.h"
 
-MainWindow::MainWindow() : mainIcon_()
+MainWindow::MainWindow() :
+    recentFiles( Persistent<RecentFiles>( "recentFiles" ) ), mainIcon_()
 {
-    // Register the operators for serializable classes
-    qRegisterMetaTypeStreamOperators<SavedSearches>( "SavedSearches" );
-    qRegisterMetaTypeStreamOperators<Filter>( "Filter" );
-    qRegisterMetaTypeStreamOperators<FilterSet>( "FilterSet" );
-
     createActions();
     createMenus();
     // createContextMenu();
@@ -104,8 +103,8 @@ void MainWindow::loadInitialFile( QString fileName )
 
 void MainWindow::createCrawler()
 {
-    // First create the searches history
-    savedSearches = new SavedSearches();
+    // First get the global search history
+    savedSearches = &(Persistent<SavedSearches>( "savedSearches" ));
 
     crawlerWidget = new CrawlerWidget( savedSearches );
 }
@@ -311,7 +310,7 @@ void MainWindow::about()
 #ifdef GLOGG_COMMIT
                 "<p>Built " GLOGG_DATE " from " GLOGG_COMMIT
 #endif
-                "<p>Copyright &copy; 2009, 2010 Nicolas Bonnefon and other contributors"
+                "<p>Copyright &copy; 2009, 2010, 2011 Nicolas Bonnefon and other contributors"
                 "<p>You may modify and redistribute the program under the terms of the GPL (version 3 or later)." ) );
 }
 
@@ -334,10 +333,15 @@ void MainWindow::lineNumberHandler( int line )
 void MainWindow::updateLoadingProgress( int progress )
 {
     LOG(logDEBUG) << "Loading progress: " << progress;
-    infoLine->setText( loadingFileName + tr( " - Indexing lines... (%1 %)" ).arg( progress ) );
-    infoLine->displayGauge( progress );
 
-    stopAction->setEnabled( true );
+    // We ignore 0% and 100% to avoid a flash when the file (or update)
+    // is very short.
+    if ( progress > 0 && progress < 100 ) {
+        infoLine->setText( loadingFileName + tr( " - Indexing lines... (%1 %)" ).arg( progress ) );
+        infoLine->displayGauge( progress );
+
+        stopAction->setEnabled( true );
+    }
 }
 
 void MainWindow::displayNormalStatus( bool success )
@@ -451,10 +455,12 @@ void MainWindow::setCurrentFile( const QString& fileName )
     currentFile = fileName;
     QString shownName = tr( "Untitled" );
     if ( !currentFile.isEmpty() ) {
-        shownName = strippedName( currentFile );
-        recentFiles.removeAll( currentFile );
-        recentFiles.prepend( currentFile );
+        // (reload the list first in case another glogg changed it)
+        GetPersistentInfo().retrieve( "recentFiles" );
+        recentFiles.addRecent( currentFile );
+        GetPersistentInfo().save( "recentFiles" );
         updateRecentFileActions();
+        shownName = strippedName( currentFile );
     }
 
     setWindowTitle(
@@ -465,22 +471,17 @@ void MainWindow::setCurrentFile( const QString& fileName )
             );
 }
 
-// Trims the recent file lists and updates the actions.
+// Updates the actions for the recent files.
 // Must be called after having added a new name to the list.
 void MainWindow::updateRecentFileActions()
 {
-    // First remove non existent files
-    QMutableStringListIterator i(recentFiles);
-    while ( i.hasNext() ) {
-        if ( !QFile::exists(i.next()) )
-            i.remove();
-    }
+    QStringList recent_files = recentFiles.recentFiles();
 
     for ( int j = 0; j < MaxRecentFiles; ++j ) {
-        if ( j < recentFiles.count() ) {
-            QString text = tr("&%1 %2").arg(j + 1).arg(strippedName(recentFiles[j]));
+        if ( j < recent_files.count() ) {
+            QString text = tr("&%1 %2").arg(j + 1).arg(strippedName(recent_files[j]));
             recentFileActions[j]->setText( text );
-            recentFileActions[j]->setData( recentFiles[j] );
+            recentFileActions[j]->setData( recent_files[j] );
             recentFileActions[j]->setVisible( true );
         }
         else {
@@ -492,44 +493,36 @@ void MainWindow::updateRecentFileActions()
 }
 
 // Write settings to permanent storage
-// It uses Qt settings storage.
 void MainWindow::writeSettings()
 {
-    QSettings settings( "glogg", "glogg" );
-
-    // Geometry of us and crawlerWidget (splitter pos, etc...)
-    settings.setValue( "geometry", saveGeometry() );
-    settings.setValue( "crawlerWidget", crawlerWidget->saveState() );
-
-    // Current file and history
-    settings.setValue( "currentFile", currentFile );
-    settings.setValue( "recentFiles", recentFiles );
-
-    // Searches history
-    settings.setValue( "savedSearches", QVariant::fromValue( *savedSearches ) );
+    // Save the session
+    SessionInfo& session = Persistent<SessionInfo>( "session" );
+    session.setGeometry( saveGeometry() );
+    session.setCrawlerState( crawlerWidget->saveState() );
+    session.setCurrentFile( currentFile );
+    GetPersistentInfo().save( QString( "session" ) );
 
     // User settings
-    Config().writeToSettings( settings );
+    GetPersistentInfo().save( QString( "settings" ) );
 }
 
 // Read settings from permanent storage
-// It uses Qt settings storage.
 void MainWindow::readSettings()
 {
-    QSettings settings( "glogg", "glogg" );
-
-    restoreGeometry( settings.value("geometry").toByteArray() );
-    crawlerWidget->restoreState( settings.value("crawlerWidget").toByteArray() );
-
-    recentFiles = settings.value("recentFiles").toStringList();
-    previousFile = settings.value("currentFile").toString();
+    // Get and restore the session
+    GetPersistentInfo().retrieve( QString( "session" ) );
+    SessionInfo session = Persistent<SessionInfo>( "session" );
+    restoreGeometry( session.geometry() );
+    crawlerWidget->restoreState( session.crawlerState() );
+    previousFile = session.currentFile();
 
+    // History of recent files
+    GetPersistentInfo().retrieve( QString( "recentFiles" ) );
     updateRecentFileActions();
 
-    // Copy the searches from the config file to our list
-    *savedSearches = settings.value( "savedSearches" ).value<SavedSearches>();
-
-    Config().readFromSettings( settings );
+    GetPersistentInfo().retrieve( QString( "savedSearches" ) );
+    GetPersistentInfo().retrieve( QString( "settings" ) );
+    GetPersistentInfo().retrieve( QString( "filterSet" ) );
 }
 
 // Returns the size in human readable format
